==> rc-ui-lib-0.1.59.tgz: package/es/form/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { act } from 'react-dom/test-utils';
import { sleep } from '../../../tests/utils';
import { toArray } from '../../uploader/utils';
import Button from '../../button';
import Field from '../../field';
import Form from '..';

var changeValue = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(wrapper, value) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper.find('input').simulate('change', {
              target: {
                value: value
              }
            });
            _context2.next = 3;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
              return _regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      _context.next = 2;
                      return sleep();

                    case 2:
                    case "end":
                      return _context.stop();
                  }
                }
              }, _callee);
            })));

          case 3:
            wrapper.update();

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function changeValue(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

export function getNamePath(path) {
  return toArray(path);
}
export function matchNamePath(namePath, changedNamePath) {
  if (!namePath || !changedNamePath || namePath.length !== changedNamePath.length) {
    return false;
  }

  return namePath.every(function (nameUnit, i) {
    return changedNamePath[i] === nameUnit;
  });
}
export function getField(wrapper) {
  var index = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

  if (typeof index === 'number') {
    return wrapper.find(Field).at(index);
  }

  var name = getNamePath(index);
  var fields = wrapper.find(Field);

  for (var i = 0; i < fields.length; i += 1) {
    var field = fields.at(i);
    var fieldName = getNamePath(field.props().name);

    if (matchNamePath(name, fieldName)) {
      return field;
    }
  }

  return null;
}
describe('Form', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('basic usage', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var onClick;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            onClick = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, {
              layout: "horizontal",
              colon: true,
              inset: true,
              footer: /*#__PURE__*/React.createElement("div", {
                style: {
                  margin: '16px 16px 0'
                }
              }, /*#__PURE__*/React.createElement(Button, {
                round: true,
                nativeType: "submit",
                type: "primary",
                block: true
              }, "\u63D0\u4EA4"))
            }, /*#__PURE__*/React.createElement(Form.Item, {
              disabled: true,
              tooltip: {
                message: 'A prime is a natural number greater than 1 that has no positive divisors other than 1 and itself.'
              },
              intro: "\u786E\u4FDD\u8FD9\u662F\u552F\u4E00\u7684\u7528\u6237\u540D",
              rules: [{
                required: true,
                message: '请填写用户名'
              }],
              name: "username",
              label: "\u7528\u6237\u540D"
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u7528\u6237\u540D"
            })), /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                required: false,
                message: '请填写密码'
              }],
              label: "\u5BC6\u7801",
              className: "my-password",
              colon: true,
              labelWidth: "100",
              labelAlign: "center",
              labelClass: "my-label-class",
              onClick: onClick
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 3:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('when noStyle props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              noStyle: true
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('when shouldUpdate props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              shouldUpdate: true
            }, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it("shouldn't work when shouldUpdate is set", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var spy;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            spy = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              dependencies: ['field_2'],
              shouldUpdate: function shouldUpdate() {
                return true;
              }
            }, function () {
              spy();
              return 'gogogo';
            }), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_1"
            }, /*#__PURE__*/React.createElement(Field, null)), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_2"
            }, /*#__PURE__*/React.createElement(Field, null))));
            expect(spy).toHaveBeenCalledTimes(1);
            _context6.next = 5;
            return changeValue(getField(wrapper, 1), 'value1');

          case 5:
            // sync start
            //   valueUpdate -> rerender by shouldUpdate
            //   depsUpdate  -> rerender by deps
            //   [ react rerender once -> 2 ]
            // sync end
            expect(spy).toHaveBeenCalledTimes(2);
            _context6.next = 8;
            return changeValue(getField(wrapper, 2), 'value2');

          case 8:
            // sync start
            //   valueUpdate -> rerender by shouldUpdate
            //   depsUpdate  -> rerender by deps
            //   [ react rerender once -> 3 ]
            // sync end
            expect(spy).toHaveBeenCalledTimes(3);

          case 9:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('when rules without reqiured props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                pattern: /\d{6}/,
                message: '请输入6位数字'
              }]
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('when rules with reqiured props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                pattern: /\d{6}/,
                message: '请输入6位数字',
                required: true
              }]
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('when name props is set without shouldUpdate or dependencies', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              name: "name"
            }, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('when shouldUpdate and dependencies are not set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, null, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('dependencies is set and name is not set ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var x;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            x = 0;
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              dependencies: ['field_1']
            }, function () {
              x += 1;
              return "gogogo".concat(x);
            }), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_1"
            }, /*#__PURE__*/React.createElement("input", null))));

          case 2:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('when children is not validElement', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    var handleBlur;
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            handleBlur = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              name: "test",
              trigger: "blur"
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801",
              onBlur: handleBlur
            }))));
            wrapper.find('input').simulate('focus');
            _context12.next = 5;
            return sleep(20);

          case 5:
            _context12.next = 7;
            return wrapper.find('input').simulate('blur');

          case 7:
            expect(handleBlur).toHaveBeenCalled(); // expect(toJson(wrapper.html())).toMatchSnapshot();

          case 8:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/es/form/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { act } from 'react-dom/test-utils';
import { sleep } from '../../../tests/utils';
import { toArray } from '../../uploader/utils';
import Button from '../../button';
import Field from '../../field';
import Form from '..';

var changeValue = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(wrapper, value) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper.find('input').simulate('change', {
              target: {
                value: value
              }
            });
            _context2.next = 3;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
              return _regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      _context.next = 2;
                      return sleep();

                    case 2:
                    case "end":
                      return _context.stop();
                  }
                }
              }, _callee);
            })));

          case 3:
            wrapper.update();

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function changeValue(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

export function getNamePath(path) {
  return toArray(path);
}
export function matchNamePath(namePath, changedNamePath) {
  if (!namePath || !changedNamePath || namePath.length !== changedNamePath.length) {
    return false;
  }

  return namePath.every(function (nameUnit, i) {
    return changedNamePath[i] === nameUnit;
  });
}
export function getField(wrapper) {
  var index = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

  if (typeof index === 'number') {
    return wrapper.find(Field).at(index);
  }

  var name = getNamePath(index);
  var fields = wrapper.find(Field);

  for (var i = 0; i < fields.length; i += 1) {
    var field = fields.at(i);
    var fieldName = getNamePath(field.props().name);

    if (matchNamePath(name, fieldName)) {
      return field;
    }
  }

  return null;
}
describe('Form', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('basic usage', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var onClick;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            onClick = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, {
              layout: "horizontal",
              colon: true,
              inset: true,
              footer: /*#__PURE__*/React.createElement("div", {
                style: {
                  margin: '16px 16px 0'
                }
              }, /*#__PURE__*/React.createElement(Button, {
                round: true,
                nativeType: "submit",
                type: "primary",
                block: true
              }, "\u63D0\u4EA4"))
            }, /*#__PURE__*/React.createElement(Form.Item, {
              disabled: true,
              tooltip: {
                message: 'A prime is a natural number greater than 1 that has no positive divisors other than 1 and itself.'
              },
              intro: "\u786E\u4FDD\u8FD9\u662F\u552F\u4E00\u7684\u7528\u6237\u540D",
              rules: [{
                required: true,
                message: '请填写用户名'
              }],
              name: "username",
              label: "\u7528\u6237\u540D"
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u7528\u6237\u540D"
            })), /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                required: false,
                message: '请填写密码'
              }],
              label: "\u5BC6\u7801",
              className: "my-password",
              colon: true,
              labelWidth: "100",
              labelAlign: "center",
              labelClass: "my-label-class",
              onClick: onClick
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 3:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('when noStyle props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              noStyle: true
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('when shouldUpdate props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              shouldUpdate: true
            }, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it("shouldn't work when shouldUpdate is set", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var spy;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            spy = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              dependencies: ['field_2'],
              shouldUpdate: function shouldUpdate() {
                return true;
              }
            }, function () {
              spy();
              return 'gogogo';
            }), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_1"
            }, /*#__PURE__*/React.createElement(Field, null)), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_2"
            }, /*#__PURE__*/React.createElement(Field, null))));
            expect(spy).toHaveBeenCalledTimes(1);
            _context6.next = 5;
            return changeValue(getField(wrapper, 1), 'value1');

          case 5:
            // sync start
            //   valueUpdate -> rerender by shouldUpdate
            //   depsUpdate  -> rerender by deps
            //   [ react rerender once -> 2 ]
            // sync end
            expect(spy).toHaveBeenCalledTimes(2);
            _context6.next = 8;
            return changeValue(getField(wrapper, 2), 'value2');

          case 8:
            // sync start
            //   valueUpdate -> rerender by shouldUpdate
            //   depsUpdate  -> rerender by deps
            //   [ react rerender once -> 3 ]
            // sync end
            expect(spy).toHaveBeenCalledTimes(3);

          case 9:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('when rules without reqiured props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                pattern: /\d{6}/,
                message: '请输入6位数字'
              }]
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('when rules with reqiured props is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              rules: [{
                pattern: /\d{6}/,
                message: '请输入6位数字',
                required: true
              }]
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
            }))));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('when name props is set without shouldUpdate or dependencies', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              name: "name"
            }, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('when shouldUpdate and dependencies are not set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, null, function () {
              return /*#__PURE__*/React.createElement(Field, {
                placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801"
              });
            })));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('dependencies is set and name is not set ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var x;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            x = 0;
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              dependencies: ['field_1']
            }, function () {
              x += 1;
              return "gogogo".concat(x);
            }), /*#__PURE__*/React.createElement(Form.Item, {
              name: "field_1"
            }, /*#__PURE__*/React.createElement("input", null))));

          case 2:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('when children is not validElement', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    var handleBlur;
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            handleBlur = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Form, null, /*#__PURE__*/React.createElement(Form.Item, {
              name: "test",
              trigger: "blur"
            }, /*#__PURE__*/React.createElement(Field, {
              placeholder: "\u8BF7\u8F93\u5165\u5BC6\u7801",
              onBlur: handleBlur
            }))));
            wrapper.find('input').simulate('focus');
            _context12.next = 5;
            return sleep(20);

          case 5:
            _context12.next = 7;
            return wrapper.find('input').simulate('blur');

          case 7:
            expect(handleBlur).toHaveBeenCalled(); // expect(toJson(wrapper)).toMatchSnapshot();

          case 8:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
});
